@@ -258,6 +258,7 @@ tab_model_df <- function(x,
                          icc.list,
                          dev.list,
                          aic.list,
+                         aicc.list,
                          variance.list,
                          ngrps.list,
                          loglik.list,
@@ -662,7 +663,7 @@ tab_model_df <- function(x,
       else
         colspan <- length(string_ends_with(sprintf("_%i", i), x = colnames(x)))
 
-      if (is.null(rsq.list[[i]])) {
+      if (is.null(rsq.list[[i]]) || all(is.na(rsq.list[[i]])) || all(sjmisc::is_empty(rsq.list[[i]], first.only = FALSE))) {
 
         page.content <- paste0(
           page.content,
@@ -732,6 +733,21 @@ tab_model_df <- function(x,
   }
 
 
+  # add aicc ----
+
+  if (!is_empty_list(aicc.list)) {
+    page.content <- paste0(page.content, create_stats(
+      data.list = aicc.list,
+      data.string = "AICc",
+      firstsumrow = firstsumrow,
+      summary.css = summary.css,
+      var.names = colnames(x),
+      n.cols = ncol(x)
+    ))
+    firstsumrow <- FALSE
+  }
+
+
   # add logLik ----
 
   if (!is_empty_list(loglik.list)) {
