@@ -27,6 +27,8 @@ get_tidy_data <- function(model, ci.lvl, tf, type, bpe, facets, show.zeroinf, p.
     tidy_stan_model(model, ci.lvl, tf, type, bpe, show.zeroinf, facets, ...)
   else if (inherits(model, "lme"))
     tidy_lme_model(model, ci.lvl)
+  else if (inherits(model, "wblm"))
+    tidy_panelr_model(model, ci.lvl)
   else if (inherits(model, "gls"))
     tidy_gls_model(model, ci.lvl)
   else if (inherits(model, "coxph"))
@@ -116,7 +118,7 @@ tidy_generic <- function(model, ci.lvl, facets, p.val) {
       if (!obj_has_name(dat, "p.value"))
         dat$p.value <- tryCatch(
           {
-            sjstats::p_value(model, p.kr = FALSE)[["p.value"]]
+            suppressMessages(sjstats::p_value(model, p.kr = FALSE)[["p.value"]])
           },
           error = function(x) { NA }
         )
@@ -189,6 +191,18 @@ tidy_cox_model <- function(model, ci.lvl) {
 }
 
 
+#' @importFrom broom tidy
+tidy_panelr_model <- function(model, ci.lvl) {
+  # tidy the model
+  dat <- broom::tidy(model, conf.int = TRUE, conf.level = ci.lvl, effects = "fixed")
+  grp_column <- grep("group", colnames(dat), fixed = TRUE)
+  if (length(grp_column)) {
+    colnames(dat)[grp_column] <- "wrap.facet"
+  }
+  dat
+}
+
+
 #' @importFrom stats mad formula
 #' @importFrom bayestestR ci
 #' @importFrom insight is_multivariate model_info
